@@ -10,7 +10,7 @@ class additional_standard_deduction(Variable):
     reference = "https://www.law.cornell.edu/uscode/text/26/63#f"
 
     def formula(tax_unit, period, parameters):
-        std = parameters(period).irs.deductions.standard
+        std = parameters(period).gov.irs.deductions.standard
         filing_status = tax_unit("filing_status", period)
         filing_statuses = filing_status.possible_values
         blind_head = tax_unit("blind_head", period) * 1
