@@ -13,7 +13,7 @@ class is_ca_cvrp_increased_rebate_eligible(Variable):
         # Use school meal FPG ratio.
         spm_unit = person.spm_unit
         fpg_ratio = spm_unit("school_meal_fpg_ratio", period)
-        p = parameters(period).states.ca.calepa.carb.cvrp.increased_rebate
+        p = parameters(period).gov.states.ca.calepa.carb.cvrp.increased_rebate
         income_eligible = fpg_ratio <= p.fpl_limit
         categorically_eligible = (
             aggr(spm_unit, period, p.categorical_eligibility) > 0
